Mixed-up Code Questions
-----------------------

.. selectquestion:: cndtnl-mixed-three_sq
   :fromid: cndtnl-mixed-three, cndtnl-mixed-three_write
   :toggle:


.. selectquestion:: cndtnl-mixed-hi_sq
   :fromid: cndtnl-mixed-hi, cndtnl-mixed-hi_write
   :toggle:


.. selectquestion:: cndtnl-mixed-price_v2_sq
   :fromid: cndtnl-mixed-price_v2, cndtnl-mixed-price_write
   :toggle:
   
          
.. selectquestion:: cndtnl-mixed-ten_sq
   :fromid: cndtnl-mixed-ten, cndtnl-mixed-ten_write
   :toggle:


.. selectquestion:: cndtnl-mixed-twelve_sq
   :fromid: cndtnl-mixed-twelve, cndtnl-mixed-twelve_write
   :toggle:


.. selectquestion:: cndtnl-mixed-nested_sq
   :fromid: cndtnl-mixed-nested, cndtnl-mixed-twelve_write
   :toggle:


.. selectquestion:: cndtnl-mixed-logical_sq
   :fromid: cndtnl-mixed-logical, cndtnl-mixed-logical_write
   :toggle:
  
.. selectquestion:: cndtnl-mixed-grade_sq
   :fromid: cndtnl-mixed-grade, cndtnl-mixed-grade_write
   :toggle:


.. selectquestion:: cndtnl-mixed-even_sq
   :fromid: cndtnl-mixed-even, cndtnl-mixed-even_write
   :toggle:


.. selectquestion:: cndtnl-mixed-goodJob_sq
   :fromid: cndtnl-mixed-goodJob, cndtnl-mixed-goodJob_write
   :toggle:  
